setClass(
  Class = "timeS4",
  representation(hour="integer", minute="integer", second="integer"),
  validity = function(object){
    if(object@hour > 23 || object@hour < 0 )
      stop("Niedopuszczalna wartosc godzinowa")
    if(object@minute > 59 || object@minute < 0 )
      stop("Niedopuszczalna wartosc minutowa")
    if(object@second > 59 || object@second < 0 )
      stop("Niedopuszczalna wartosc sekundowa")
    return (TRUE)
  }
)

setMethod(
  f  ="initialize",
  signature = "timeS4",
  definition = function(.Object, hour = integer(0), minute = integer(0), second=integer(0)) {
    if(!missing(hour) && !missing(minute) && !missing(second)){
      .Object@hour <- as.integer(hour)
      .Object@minute <- as.integer(minute)
      .Object@second <- as.integer(second)
      validObject(.Object)
    }
    return(.Object)
  }
)

setMethod(
  f = "summary",
  signature = "timeS4",
  definition = function(object) {
    cat("Timestamp zapisany w formacie 24-godzinnym hh:mm:ss \n", object@hour,":", object@minute,":", object@second, "\n")
    if(object@hour>12){
      cat("Timestamp zapisany w formacie 12-godzinnym hh:mm:ss \n", object@hour-12,":", object@minute,":", object@second, "PM\n")
    } else cat("Timestamp zapisany w formacie 12-godzinnym hh:mm:ss \n", object@hour,":", object@minute,":", object@second, "AM\n")
  }
)


setMethod(
  f = "plot",
  signature = "timeS4",
  definition = function(x, col.rect="lightsteelblue1", col.mark="black", col.title="blue", col.axes="black") {
    plot.new()
    plot.window(xlim=c(0.5,8.5), ylim=c(0.5,4.5))
	rect(0.5,0.5,2.5,4.5, col=col.rect)
    rect(3.5,0.5,5.5,4.5, col=col.rect)
    rect(6.5,0.5,8.5,4.5, col=col.rect)
    Binary.points(x@hour,1,cex=2, pch=22, bg=col.mark)
    Binary.points(x@minute,4,cex=2, pch=22, bg=col.mark)
    Binary.points(x@second,7,cex=2, pch=22, bg=col.mark)
    mtext(c("H","H","M","M","S","S"), side=1, at=c(1,2,4,5,7,8), las=1, cex=2, col=col.axes)
    mtext(c("1","2","4","8"), side=2, at=c(1,2,3,4), las=1, cex=2, col=col.axes)
	mtext("Timestamp w formie zegara binarnego", side=3, cex=2.1, col=col.title)
  }
)
